Option Strict On
Option Explicit On 

Imports Interop.QBFC5
Module BuildSalesReceiptAddRqModule

    Public Sub BuildSalesReceiptAddRq(ByVal order As Order, ByVal requestMsgSet As IMsgSetRequest, ByVal country As String)

        If (requestMsgSet Is Nothing) Then
            Exit Sub
        End If

        'Add the request to the message set request object.
        Dim salesReceiptAdd As ISalesReceiptAdd
        salesReceiptAdd = requestMsgSet.AppendSalesReceiptAddRq()
        salesReceiptAdd.CustomerRef.ListID.SetValue(order.customerListId)
        salesReceiptAdd.ClassRef.FullName.SetValue(order.className)
        salesReceiptAdd.TxnDate.SetValue(CType(order.transactionDate, Date))
        salesReceiptAdd.RefNumber.SetValue(order.id)
        '' Addr1 = Company Name
        '' Addr2 = FirstName & LastName
        salesReceiptAdd.BillAddress.Addr1.SetValue(order.billingCompany)
        salesReceiptAdd.BillAddress.Addr2.SetValue(order.billingName)
        salesReceiptAdd.BillAddress.Addr3.SetValue(order.billingStreetAddress)
        salesReceiptAdd.BillAddress.City.SetValue(order.billingCity)
        salesReceiptAdd.BillAddress.State.SetValue(order.billingState)
        salesReceiptAdd.BillAddress.PostalCode.SetValue(order.billingPostcode)
        salesReceiptAdd.BillAddress.Country.SetValue(order.billingCountry)
        salesReceiptAdd.ShipAddress.Addr1.SetValue(order.shippingCompany)
        salesReceiptAdd.ShipAddress.Addr2.SetValue(order.shippingName)
        salesReceiptAdd.ShipAddress.Addr3.SetValue(order.shippingStreetAddress)
        salesReceiptAdd.ShipAddress.City.SetValue(order.shippingCity)
        salesReceiptAdd.ShipAddress.State.SetValue(order.shippingState)
        salesReceiptAdd.ShipAddress.PostalCode.SetValue(order.shippingPostcode)
        salesReceiptAdd.ShipAddress.Country.SetValue(order.shippingCountry)
        salesReceiptAdd.Memo.SetValue(order.notes)


        If order.shipMethod.ToUpper.IndexOf("FEDERAL EXPRESS") >= 0 Then
            salesReceiptAdd.ShipMethodRef.FullName.SetValue("Federal Express")
        ElseIf order.shipMethod.ToUpper.IndexOf("UNITED STATES POSTAL SERVICE") >= 0 Then
            salesReceiptAdd.ShipMethodRef.FullName.SetValue("USPS")
        ElseIf order.shipMethod.ToUpper.IndexOf("UNITED PARCEL SERVICE") >= 0 Then
            salesReceiptAdd.ShipMethodRef.FullName.SetValue("UPS")
        End If

        If Len(order.paymentMethod) > 0 Then
            salesReceiptAdd.PaymentMethodRef.FullName.SetValue(order.paymentMethod)
        End If
        salesReceiptAdd.ShipDate.SetValue(CType(order.shipDate, Date))
        salesReceiptAdd.ClassRef.FullName.SetValue(order.className)

        ' Set the value of the ISalesReceiptAdd.IsToBePrinted element.
        salesReceiptAdd.IsToBePrinted.SetValue(True)

        If Len(order.depositAccount) > 0 Then
            salesReceiptAdd.DepositToAccountRef.FullName.SetValue(order.depositAccount)
        End If

        'Add multiple elements to the list. In this case we will add 5 elements.
        Dim orSalesReceiptLineAdd1 As IORSalesReceiptLineAdd
        Dim j As Integer
        If Not order.lineItems Is Nothing Then
            For j = 0 To order.lineItems.Length - 1
                Dim item As OrderLineItem = order.lineItems(j)
                orSalesReceiptLineAdd1 = salesReceiptAdd.ORSalesReceiptLineAddList.Append()
                orSalesReceiptLineAdd1.SalesReceiptLineAdd.ItemRef.FullName.SetValue(item.itemRefName)
                orSalesReceiptLineAdd1.SalesReceiptLineAdd.Desc.SetValue(item.description)
                orSalesReceiptLineAdd1.SalesReceiptLineAdd.Quantity.SetValue(item.quantity)
                orSalesReceiptLineAdd1.SalesReceiptLineAdd.ORRatePriceLevel.Rate.SetValue(item.amount)
                If item.isTaxable Then
                    orSalesReceiptLineAdd1.SalesReceiptLineAdd.SalesTaxCodeRef.FullName.SetValue("Tax")
                Else
                    orSalesReceiptLineAdd1.SalesReceiptLineAdd.SalesTaxCodeRef.FullName.SetValue("Non")
                End If
            Next
        End If
        salesReceiptAdd.IncludeRetElementList.Add("EditSequence")
        salesReceiptAdd.IncludeRetElementList.Add("ListID")
        salesReceiptAdd.IncludeRetElementList.Add("RefNumber")
    End Sub
End Module
