Imports Interop.QBFC5
Module ProcessResponseModule


    Public Sub processCustomerResponse(ByVal msgResponse As IMsgSetResponse)
        Dim responseType As IResponseType
        If msgResponse Is Nothing Then
            Return
        End If
        ' Now Handle Each Response
        Dim i As Integer
        Dim response As IResponse
        For i = 0 To msgResponse.ResponseList.Count - 1
            response = msgResponse.ResponseList.GetAt(i)
            responseType = response.Type

            If response.StatusCode >= 0 Then
                If response.StatusCode > 0 Then
                    ' A Warning From Quickbooks!
                    Debug.Write("Response#: " & i & vbCrLf)
                    Debug.Write("WARNING: " & response.StatusMessage)
                End If
                If (responseType.GetValue = ENResponseType.rtCustomerAddRs Or responseType.GetValue = ENResponseType.rtCustomerModRs) Then
                    ''
                    '' Process CustomerRet or CustomerRetList
                    ''
                    processCustomerRet(response.Detail)
                    Application.DoEvents()
                ElseIf (responseType.GetValue = ENResponseType.rtCustomerQueryRs) Then
                    Dim j As Integer
                    Dim customerRetList As ICustomerRetList
                    customerRetList = CType(response.Detail, ICustomerRetList)
                    For j = 0 To customerRetList.Count - 1
                        Application.DoEvents()
                        processCustomerRet(customerRetList.GetAt(j))
                    Next
                End If
            ElseIf response.StatusCode < 0 Then
                Debug.Write("ERROR: " & response.StatusMessage)
            End If
        Next
        Debug.WriteLine("==============================================")
        Debug.Write(msgResponse.ToXMLString)


    End Sub

    Public Function ParseInventoryAdjustmentAddRs(ByVal responseMsgSet As IMsgSetResponse) As IInventoryAdjustmentRet

        If (responseMsgSet Is Nothing) Then
            Exit Function
        End If

        Dim responseList As IResponseList
        responseList = responseMsgSet.ResponseList
        If (responseList Is Nothing) Then
            Exit Function
        End If

        ' Go through all of the responses in the list. 
        Dim i As Integer
        For i = 0 To responseList.Count - 1
            Dim response As IResponse
            response = responseList.GetAt(i)

            ' Check the status returned for the response. 
            If (response.StatusCode = 0) Then

                ' Check to make sure the response is of the type we are expecting. 
                If (Not response.Detail Is Nothing) Then
                    Dim responseType As Short
                    responseType = response.Type.GetValue()
                    Dim j As Integer
                    ' Check for InventoryAdjustmentAddRs. 
                    If (responseType = ENResponseType.rtInventoryAdjustmentAddRs) Then
                        Dim inventoryAdjustmentRet As IInventoryAdjustmentRet
                        inventoryAdjustmentRet = CType(response.Detail, IInventoryAdjustmentRet)
                        ParseInventoryAdjustmentAddRs = inventoryAdjustmentRet
                    End If
                End If
            End If
        Next i
    End Function


    Public Function parseItemInventoryQueryRet(ByVal responseMsgSet As IMsgSetResponse) As IItemInventoryRet
        If (responseMsgSet Is Nothing) Then
            Exit Function
        End If

        Dim responseList As IResponseList
        responseList = responseMsgSet.ResponseList
        If (responseList Is Nothing) Then
            Exit Function
        End If

        ' Go through all of the responses in the list. 
        Dim i As Integer
        For i = 0 To responseList.Count - 1
            Dim response As IResponse
            response = responseList.GetAt(i)

            ' Check the status returned for the response. 
            If (response.StatusCode = 0) Then

                ' Check to make sure the response is of the type we are expecting. 
                If (Not response.Detail Is Nothing) Then
                    Dim responseType As Short
                    responseType = response.Type.GetValue()
                    Dim j As Integer
                    ' Check for ItemInventoryQueryRs. 
                    If (responseType = ENResponseType.rtItemInventoryQueryRs) Then
                        Dim itemInventoryRetList As IItemInventoryRetList
                        itemInventoryRetList = CType(response.Detail, IItemInventoryRetList)
                        If itemInventoryRetList.Count = 1 Then
                            parseItemInventoryQueryRet = itemInventoryRetList.GetAt(0)
                        End If
                    End If
                End If
            End If
        Next i
    End Function

    Public Sub processItemInventoryResponse(ByVal msgResponse As IMsgSetResponse)
        Dim responseType As IResponseType
        Dim sql As String
        If msgResponse Is Nothing Then
            Return
        End If
        ' Now Handle Each Response
        Dim i As Integer
        Dim response As IResponse
        For i = 0 To msgResponse.ResponseList.Count - 1
            response = msgResponse.ResponseList.GetAt(i)
            responseType = response.Type

            If response.StatusCode >= 0 Then
                If response.StatusCode > 0 Then
                    ' A Warning From Quickbooks!
                    Debug.Write("WARNING: " & response.StatusMessage)
                End If
                If (responseType.GetValue = ENResponseType.rtItemInventoryAddRs Or responseType.GetValue = ENResponseType.rtItemInventoryModRs) Then
                    ' Process if ResponseType was CustomerAddRs or CustomerModRs
                    Dim itemRet As IItemInventoryRet
                    itemRet = response.Detail
                    ' Process Each Element of the Response:

                    Dim itemName = itemRet.Name.GetValue
                    Dim itemEditSequence = itemRet.EditSequence.GetValue
                    Dim itemListId = itemRet.ListID.GetValue
                    Dim item_id As String
                    If IsNumeric(itemName) Then
                        Try
                            Dim item As New Item
                            item.id = itemName
                            item.listId = itemListId
                            item.editSequence = itemEditSequence
                            sql = "UPDATE products SET qb_list_id='" & item.listId & "', qb_edit_seq='" & item.editSequence & "' " & _
                            "WHERE products_id='" & item.id & "'"
                            Debug.WriteLine(sql)
                            dbConn.Execute(sql)
                        Catch ex As Exception
                            Debug.WriteLine("BAD FORMAT: " & itemName)
                        End Try
                    End If
                ElseIf (responseType.GetValue = ENResponseType.rtItemInventoryQueryRs) Then
                    Dim j As Integer
                    Dim itemInventoryRetList As IItemInventoryRetList
                    If Not response.Detail Is Nothing Then
                        itemInventoryRetList = CType(response.Detail, IItemInventoryRetList)
                        For j = 0 To itemInventoryRetList.Count - 1
                            Application.DoEvents()
                            processItemInventoryRet(itemInventoryRetList.GetAt(j))
                        Next
                    End If
                End If
            ElseIf response.StatusCode < 0 Then
                Debug.Write("ERROR: " & response.StatusMessage)
            End If
        Next
        Debug.WriteLine("==============================================")
        Debug.Write(msgResponse.ToXMLString)

    End Sub

    Public Sub processTransactionResponse(ByVal msgResponse As IMsgSetResponse)
        Dim responseType As IResponseType
        Dim sql As String
        If msgResponse Is Nothing Then
            Return
        End If
        ' Now Handle Each Response
        Dim i As Integer
        Dim response As IResponse
        For i = 0 To msgResponse.ResponseList.Count - 1
            response = msgResponse.ResponseList.GetAt(i)
            responseType = response.Type

            If response.StatusCode >= 0 Then
                If response.StatusCode > 0 Then
                    ' A Warning From Quickbooks!
                    Debug.Write("WARNING: " & response.StatusMessage)
                End If
                If (responseType.GetValue = ENResponseType.rtInvoiceAddRs Or responseType.GetValue = ENResponseType.rtSalesReceiptAddRs) Then
                    ' Process if ResponseType was CustomerAddRs or CustomerModRs
                    Dim invoiceRet
                    invoiceRet = response.Detail
                    ' Process Each Element of the Response:

                    Dim itemName = invoiceRet.RefNumber.GetValue
                    Dim itemEditSequence = invoiceRet.EditSequence.GetValue
                    Dim item_id As String
                    If IsNumeric(itemName) Then
                        Try
                            Dim invoice As New Order
                            invoice.id = itemName
                            invoice.editSequence = itemEditSequence
                            sql = "UPDATE orders SET qb_edit_seq='" & invoice.editSequence & "' " & _
                            "WHERE orders_id='" & invoice.id & "'"
                            Debug.WriteLine(sql)
                            dbConn.Execute(sql)
                        Catch ex As Exception
                            Debug.WriteLine("BAD FORMAT: " & itemName)
                        End Try
                    End If
                End If
            ElseIf response.StatusCode < 0 Then
                Debug.Write("ERROR: " & response.StatusMessage)
            End If
        Next
        Debug.WriteLine("==============================================")
        Debug.Write(msgResponse.ToXMLString)

    End Sub

    Sub processCustomerRet(ByVal customerRet As ICustomerRet)

        If customerRet Is Nothing Then
            Return
        End If

        Dim sql As String

        Dim customerName As String = customerRet.Name.GetValue
        Dim customerEditSequence = customerRet.EditSequence.GetValue
        Dim customerListId = customerRet.ListID.GetValue
        Dim customers_id As String
        Dim id_length As Integer
        Dim cust As New Customer
        If (customerName.IndexOf("(") >= 0 And customerName.IndexOf(")") >= 0) Then
            id_length = (customerName.IndexOf(")")) - (customerName.IndexOf("(") + 1)
            customers_id = customerName.Substring(customerName.IndexOf("(") + 1, id_length)

            Try
                cust.id = customers_id
                cust.listId = customerListId
                cust.editSequence = customerEditSequence
                sql = "UPDATE customers SET qb_list_id='" & cust.listId & "', qb_edit_seq='" & cust.editSequence & "' " & _
                "WHERE customers_id='" & cust.id & "'"
                Debug.WriteLine(sql)
                dbConn.Execute(sql)
            Catch ex As Exception
                Debug.WriteLine("BAD FORMAT: " & customerName)
            End Try
        End If
        customerName = Nothing
        customerEditSequence = Nothing
        customerListId = Nothing
        cust = Nothing

    End Sub

    Sub processItemInventoryRet(ByVal itemInventoryRet As IItemInventoryRet)

        If itemInventoryRet Is Nothing Then
            Return
        End If

        Dim sql As String

        Dim itemInventoryName As String = itemInventoryRet.Name.GetValue
        Dim itemInventoryEditSequence = itemInventoryRet.EditSequence.GetValue
        Dim itemInventoryListId = itemInventoryRet.ListID.GetValue
        Dim products_id As String
        Dim id_length As Integer
        Dim item As New Item

        products_id = itemInventoryName

        Try
            item.id = products_id
            item.listId = itemInventoryListId
            item.editSequence = itemInventoryEditSequence
            sql = "UPDATE products SET qb_list_id='" & item.listId & "', qb_edit_seq='" & item.editSequence & "' " & _
            "WHERE products_id='" & item.id & "'"
            Debug.WriteLine(sql)
            dbConn.Execute(sql)
        Catch ex As Exception
            Debug.WriteLine("BAD FORMAT: " & itemInventoryName)
        End Try
        itemInventoryName = Nothing
        itemInventoryEditSequence = Nothing
        itemInventoryListId = Nothing
        item = Nothing

    End Sub
End Module
